@@ -169,14 +169,15 @@ class TestSKK(unittest.TestCase):
         # nX -> ンX
         self.__skk.press_key(u'n')
         self.assertEqual(self.__skk.press_key(u'.'), (True, u'ン。'))
-        # ww -> っw
-        self.__skk.reset()
-        self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
-        self.__skk.press_key(u'w')
-        handled, output = self.__skk.press_key(u'w')
-        self.assertTrue(handled)
-        self.assertEqual(output, u'っ')
-        self.assertEqual(self.__skk.preedit, u'w')
+        # ww -> っw, etc.  Issue#33.
+        for c in (u'h', u'm', u'w'):
+            self.__skk.reset()
+            self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
+            self.__skk.press_key(c)
+            handled, output = self.__skk.press_key(c)
+            self.assertTrue(handled)
+            self.assertEqual(output, u'っ')
+            self.assertEqual(self.__skk.preedit, c)
         # zl -> →
         self.__skk.reset()
         self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
@@ -361,6 +362,15 @@ class TestSKK(unittest.TestCase):
         self.__skk.press_key(u'>')
         self.assertEqual(self.__skk.preedit, u'▼超')
 
+        # Issue#28
+        self.__skk.reset()
+        self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
+        self.__skk.press_key(u'S')
+        self.__skk.press_key(u'a')
+        self.__skk.press_key(u's')
+        self.__skk.press_key(u'S')
+        self.assertEqual(self.__skk.preedit, u'▽さっ*s')
+
     def testcompletion(self):
         self.__skk.reset()
         self.__skk.activate_input_mode(skk.INPUT_MODE_HIRAGANA)
